#!/bin/bash
#%define UseAutoMake14 %(automake --version | grep -q "1\.4" && echo 0 || echo 1)
# Force GNU automake 1.4 to be used automatically
#%define __automake automake%(automake --version | grep -q "1\.4" || echo -1.4)

# Glide3 is x86/alpha/ia64 only, and ia64 is untested
ExclusiveArch: %{ix86} alpha ia64

%define OldStyleUsrLibGlide3Dir 0

Summary: Glide runtime for the 3Dfx Voodoo family of cards
Name: Glide3
Version: 20010520
Release: 25.XOS.1
# Create the Glide3 tarball by using:
#   cvs -d :pserver:anonymous@cvs.glide.sourceforge.net:/cvsroot/glide co Glide3
#   pushd Glide3 ; find . -name CVS -type d |xargs rm -rf
#   find . -name .cvsignore | xargs rm ; popd
#   tar jcf Glide3-$(date +"%Y%m%d").tar.bz2 Glide3/
Source: Glide3-%{version}.tar.bz2
Source1: glidelink.c
Patch: glide-ia64.patch
Patch1:   Glide3-new-autotools-bugfix.patch
Patch10:  Glide3-redhat-cleanup-1.patch
URL: http://glide.sourceforge.net
License: 3DFX GLIDE Source Code General Public License
Group: User Interface/X Hardware Support
Prefix: /usr
BuildRequires: automake14 autoconf213
BuildRoot: %{_tmppath}/Glide3-%{version}-root

Conflicts: XFree86-libs = 4.1.0

Prereq: /sbin/ldconfig

%define libver 3.10.0

%description
Glide3 provides the necessary low-level interface glue between the Mesa
3D graphics library, and 3Dfx Voodoo series of hardware.  This package is
required by the XFree86 tdfx driver in order to provide 3D acceleration
support for the 3Dfx Voodoo 3/4/5 and Voodoo Banshee hardware.

%package devel
Summary: Development libraries and headers for Glide
Group: Development/Libraries
Requires: Glide3 = %{version}
Conflicts: XFree86-devel = 4.1.0

%description devel
Glide3-devel contains the developmental files that must be installed in order
to recompile XFree86 on platforms which 3Dfx harware 3D acceleration is
supported on.
 
%prep
%setup -q -n Glide3

%ifarch ia64 alpha
%patch -p1 -b .glide-ia64 
%endif

%patch1 -p0 -b .new-autotools-bugfix
%patch10 -p1 -b .redhat-cleanup-1

%build

pushd .

aclocal-1.4
libtoolize --copy --force
automake-1.4 -a
autoconf-2.13

mkdir build-5
cd build-5
CFLAGS="$RPM_OPT_FLAGS" ../configure \
	--enable-fx-debug=no \
	--enable-fx-glide-hw=h5 \
	--enable-fx-dri-build \
	--prefix=/usr
make -f makefile.autoconf all
cd ..

mkdir build-3
cd build-3
CFLAGS="$RPM_OPT_FLAGS" ../configure \
	--enable-fx-debug=no \
	--enable-fx-glide-hw=h3 \
	--enable-fx-dri-build \
	--prefix=/usr
make -f makefile.autoconf all
cd ..

popd

%install
rm -rf $RPM_BUILD_ROOT

mkdir -p $RPM_BUILD_ROOT/usr/sbin
cd build-3

make -f makefile.autoconf install DESTDIR=$RPM_BUILD_ROOT

%if %{OldStyleUsrLibGlide3Dir}
%define glidedir %{_libdir}/glide3
%else
%define glidedir %{_libdir}
%endif

# Hack
mkdir -p $RPM_BUILD_ROOT/%{glidedir}
mv $RPM_BUILD_ROOT%{_libdir}/libglide3.so.%{libver} \
	$RPM_BUILD_ROOT/%{glidedir}/libglide3-v3.so
install -m 755 ../build-5/h5/glide3/src/.libs/libglide3.so.%{libver} \
	$RPM_BUILD_ROOT/%{glidedir}/libglide3-v5.so

%if %{OldStyleUsrLibGlide3Dir}
# Point to v3 by default
ln -snf glide3/libglide3-v3.so $RPM_BUILD_ROOT%{_libdir}/libglide3.so.%{libver}
%else
ln -snf libglide3-v3.so $RPM_BUILD_ROOT%{_libdir}/libglide3.so.%{libver}
%endif

# ldconfig doesn't like this?
ln -snf libglide3.so.%{libver} $RPM_BUILD_ROOT%{_libdir}/libglide3.so.3

# We are not installing these, so lets delete them
rm -f $RPM_BUILD_ROOT%{_libdir}/libglide3.{a,la}


%clean
rm -rf $RPM_BUILD_ROOT


%post
/sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%defattr(-,root,root)
%if %{OldStyleUsrLibGlide3Dir}
%dir %{_libdir}/glide3
%endif
%{_libdir}/libglide3.so.3
%{_libdir}/libglide3.so.%{libver}
%{glidedir}/libglide3-v3.so
%{glidedir}/libglide3-v5.so

%files devel
%defattr(-,root,root)
%dir %{_includedir}/glide3
%{_includedir}/glide3/*
%{_libdir}/libglide3.so

%changelog
* Fri Aug 20 2004 X/OS Linux Team <xoslinux@xos.nl> 20010520-25.XOS.1
- Build for X/OS Linux 3.0.
- X/OS Linux source rpm based on Glide3-20010520-25.src.rpm
  (md5sum of original source rpm: 192c257948c2959b1fc4a5642643f6ed).

* Wed Jan 22 2003 Tim Powers <timp@redhat.com>
- rebuilt

* Fri Dec 20 2002 Mike A. Harris <mharris@redhat.com> 20010520-24
- Reworded the -devel package description for bug (#79477)

* Mon Nov 25 2002 Mike A. Harris <mharris@redhat.com> 20010520-23
- Bump and rebuild to pick up Alpha which did not get built in -22 somehow

* Sat Nov 23 2002 Mike A. Harris <mharris@redhat.com> 20010520-22
- Moved comment from XFree86 package to here on how to create Glide3 tarball

* Fri Nov 22 2002 Mike A. Harris <mharris@redhat.com> 20010520-21
- Remove /usr/lib/libglide3.{a,la} from buildroot since we dont ship them
- Use _libdir, _includedir everywhere
- Remove redundant ExcludeArch directive for s390

* Thu Oct  3 2002 Mike A. Harris <mharris@redhat.com> 20010520-20
- All-arch rebuild
- Added "Exclusivearch: {ix86}, alpha, ia64" as Glide3 is not ported to
  other arches and likely never ever will be.  That way lays madness.

* Fri Jun 21 2002 Tim Powers <timp@redhat.com> 20010520-18
- automated rebuild

* Wed May 29 2002 Elliot Lee <sopwith@redhat.com> 20010520-17
- Make it specify the auto* tool versions explicitly.

* Tue May 28 2002 Mike A. Harris <mharris@redhat.com> 20010520-16
- Rebuilt with gcc 3.1 with new GNU autoconk/autobreak/libfool
- Added Glide3-new-autotools-bugfix.patch to fix problems with Glide automake
  files.

* Wed Apr  3 2002 Mike A. Harris <mharris@redhat.com> 20010520-13
- Removed glidelink cruft entirely.
- Simplified spec install stage, filelist, etc to minimize error potential
- Fixed dangling symlink bug (#61521)

* Sun Mar 10 2002 Mike A. Harris <mharris@redhat.com> 20010520-12
- Removed all the old /usr/lib/lib* files, and removed the /usr/lib/glide3
  directory.  Moved the Voodoo 3 and voodoo 5 glide libs directly into
  /usr/lib where the XFree86 4.2.0 tdfx dri driver will load them automatically.

* Thu Feb 21 2002 Mike A. Harris <mharris@redhat.com> 20010520-11
- Made glidelink conditional, and disabled by default, as it is not needed
  in XFree86 4.2.0 as Mesa now loads the proper Glide3 library on its own.
- Added buildrequires kudzu-devel (#59960)

* Sat Jan 26 2002 Mike A. Harris <mharris@redhat.com> 20010520-10
- Added autoconf version detection and override via __automake so Glide3 will
  build on any Red Hat Linux 7.* or rawhide system without specfile editing.
- Added -q flag to setup section

* Fri Jan 25 2002 Mike A. Harris <mharris@redhat.com> 20010520-9
- Fixed a build failure on ia64 with the ia64 patch

* Fri Jan 25 2002 Mike A. Harris <mharris@redhat.com> 20010520-8
- Undeprecated the Glide3 package that was merged into XFree86 packaging as
  it seemed to create more problems than it solved.  Took the RHL 7.2 package
  as a starting point, and deintegrated Glide from the XFree86 4.2.0 package
  back to separate packaging.  Bumped release up to -8
- Changed Copyright tag to License
- Added Glide3-redhat-cleanup-1.patch to clean up some compiler warnings.
- Added Conflicts: XFree86-libs = 4.1.0 and Conflicts: XFree86-devel = 4.1.0
- Fixed BuildRoot with _tmppath

* Mon Feb 19 2001 Bill Nottingham <notting@redhat.com>
- fix typo in ia64 patch, only apply patch on alpha/ia64 (#27889)

* Thu Dec 21 2000 Bill Nottingham <notting@redhat.com>
- fix alpha asm (rth@redhat.com)

* Wed Dec 20 2000 Bill Nottingham <notting@redhat.com>
- update CVS
- build in 7.1 tree

* Wed Aug 23 2000 Bill Nottingham <notting@redhat.com>
- initial packaging
	
